timeless

Module data

Structs

  • A struct representing data that may potentially have breaks. If you expect that you may want to store time values but not data values, use this to avoid storing blanks.